"""
Process and standardize spectroscopic analyses of CO2 isotopologues
"""

__author__    = 'Mathieu Daëron'
__contact__   = 'mathieu@daeron.fr'
__copyright__ = 'Copyright (c) 2024 Mathieu Daëron'
__license__   = 'MIT License - https://opensource.org/licenses/MIT'
__date__      = '2024-11-07'
__version__   = '0.0.2'
